install static method

void install(
  1. RuntimeContext ctx
)

Installs a pre-populated RuntimeContext. Intended to be called from generated code at the top of main() so that no mirror code is ever executed under dart compile exe.

Implementation

static void install(RuntimeContext ctx) {
  _installed = ctx;
}