runtime library

Mirror-free runtime surface used by AOT-compiled Conduit binaries.

This entrypoint is safe to import from dart compile exe-bound code: it does not transitively import dart:mirrors. The legacy mirror-based discovery, build pipeline, and Compiler machinery have been moved to package:conduit_runtime/dev.dart and are only loaded in JIT/dev workflows or by the still-supported conduit build CLI.

Classes

PreventCompilation
Prevents a type from being compiled when it otherwise would be.
RuntimeCollection
RuntimeContext
Contextual values used during runtime.

Functions

registerDefaultContextFactory(RuntimeContext factory()) → void

Exceptions / Errors

TypeCoercionException